@@ -721,6 +721,13 @@ class Shipment(AllResource, CreateResource):
         response, api_key = requestor.request('get', url, params)
         return response
 
+    def regenerate_rates(self):
+        requestor = Requestor(self._api_key)
+        url = "%s/%s" % (self.instance_url(), "rerate")
+        response, api_key = requestor.request('post', url)
+        self.refresh_from(response, api_key)
+        return self
+
     def get_rates(self):
         requestor = Requestor(self._api_key)
         url = "%s/%s" % (self.instance_url(), "rates")
@@ -733,7 +740,7 @@ class Shipment(AllResource, CreateResource):
         url = "%s/%s" % (self.instance_url(), "smartrate")
 
         response, api_key = requestor.request('get', url)
-        return response
+        return response.get('result', [])
 
     def buy(self, **params):
         requestor = Requestor(self._api_key)
